SparkWorks Python Client
========================

Management Service for the SparkWorks Processing Engine

This Python package is automatically generated by the `Swagger
Codegen <https://github.com/swagger-api/swagger-codegen>`__ project:

-  API version: v2.0
-  Package version: 1.0.0
-  Build package: io.swagger.codegen.languages.PythonClientCodegen For
   more information, please visit http://www.sparkworks.net/

Requirements.
-------------

Python 2.7 and 3.4+

Installation & Usage
--------------------

pip install
~~~~~~~~~~~

If the python package is hosted on Github, you can install directly from
Github

.. code:: sh

    pip install git+https://github.com//.git

(you may need to run ``pip`` with root permission:
``sudo pip install git+https://github.com//.git``)

Then import the package:

.. code:: python

    import sparkworks_client 

Setuptools
~~~~~~~~~~

Install via `Setuptools <http://pypi.python.org/pypi/setuptools>`__.

.. code:: sh

    python setup.py install --user

(or ``sudo python setup.py install`` to install the package for all
users)

Then import the package:

.. code:: python

    import sparkworks_client

Getting Started
---------------

Please follow the `installation procedure <#installation--usage>`__ and
then run the following:

.. code:: python

    from __future__ import print_function
    import time
    import sparkworks_client
    from sparkworks_client.rest import ApiException
    from pprint import pprint

    # Configure OAuth2 access token for authorization: oauth2
    configuration = sparkworks_client.Configuration()
    configuration.access_token = 'YOUR_ACCESS_TOKEN'

    # create an instance of the API class
    api_instance = sparkworks_client.CommandAPIApi(sparkworks_client.ApiClient(configuration))
    uuid = 'uuid_example' # str | The unique identifier of the Actuator Resource
    command_dto = sparkworks_client.CommandAPIModel() # CommandAPIModel | commandDto

    try:
        # Send a command to a SparkWorks Actuator Resource
        api_response = api_instance.send_command(uuid, command_dto)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CommandAPIApi->send_command: %s\n" % e)

Documentation for API Endpoints
-------------------------------

All URIs are relative to *https://api.sparkworks.net*

+---------------+----------------+----------------+----------------+
| Class         | Method         | HTTP request   | Description    |
+===============+================+================+================+
| *CommandAPIAp | `**send\_comma | **POST**       | Send a command |
| i*            | nd** <docs/Com | /v2/command/{u | to a           |
|               | mandAPIApi.md# | uid}           | SparkWorks     |
|               | send_command>` |                | Actuator       |
|               | __             |                | Resource       |
+---------------+----------------+----------------+----------------+
| *DataAPIApi*  | `**publish\_da | **POST**       | publishData    |
|               | ta\_using\_pos | /v2/resource/d |                |
|               | t** <docs/Data | ata/publish    |                |
|               | APIApi.md#publ |                |                |
|               | ish_data_using |                |                |
|               | _post>`__      |                |                |
+---------------+----------------+----------------+----------------+
| *DataAPIApi*  | `**query\_late | **POST**       | queryLatestSum |
|               | st\_summary\_f | /v2/resource/q | maryForResourc |
|               | or\_resources\ | uery/summary   | es             |
|               | _using\_post** |                |                |
|               |  <docs/DataAPI |                |                |
|               | Api.md#query_l |                |                |
|               | atest_summary_ |                |                |
|               | for_resources_ |                |                |
|               | using_post>`__ |                |                |
+---------------+----------------+----------------+----------------+
| *DataAPIApi*  | `**query\_late | **POST**       | queryLatestVal |
|               | st\_values\_fo | /v2/resource/q | uesForResource |
|               | r\_resources\_ | uery/latest    | s              |
|               | using\_post**  |                |                |
|               | <docs/DataAPIA |                |                |
|               | pi.md#query_la |                |                |
|               | test_values_fo |                |                |
|               | r_resources_us |                |                |
|               | ing_post>`__   |                |                |
+---------------+----------------+----------------+----------------+
| *DataAPIApi*  | `**query\_time | **POST**       | queryTimeRange |
|               | \_range\_using | /v2/resource/q |                |
|               | \_post** <docs | uery/timerange |                |
|               | /DataAPIApi.md |                |                |
|               | #query_time_ra |                |                |
|               | nge_using_post |                |                |
|               | >`__           |                |                |
+---------------+----------------+----------------+----------------+
| *DataAPIApi*  | `**retrieve\_l | **GET**        | retrieveLatest |
|               | atest\_summary | /v2/resource/{ | Summary        |
|               | \_using\_get** | uuid}/summary  |                |
|               |  <docs/DataAPI |                |                |
|               | Api.md#retriev |                |                |
|               | e_latest_summa |                |                |
|               | ry_using_get>` |                |                |
|               | __             |                |                |
+---------------+----------------+----------------+----------------+
| *DataAPIApi*  | `**retrieve\_l | **GET**        | retrieveLatest |
|               | atest\_values\ | /v2/resource/{ | Values         |
|               | _using\_get**  | uuid}/latest   |                |
|               | <docs/DataAPIA |                |                |
|               | pi.md#retrieve |                |                |
|               | _latest_values |                |                |
|               | _using_get>`__ |                |                |
+---------------+----------------+----------------+----------------+
| *GatewayAPIAp | `**count\_gate | **GET**        | Count Gateways |
| i*            | ways** <docs/G | /v2/gateway/co |                |
|               | atewayAPIApi.m | unt            |                |
|               | d#count_gatewa |                |                |
|               | ys>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *GatewayAPIAp | `**create\_gat | **POST**       | Create a new   |
| i*            | eway** <docs/G | /v2/gateway    | Gateway        |
|               | atewayAPIApi.m |                |                |
|               | d#create_gatew |                |                |
|               | ay>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *GatewayAPIAp | `**delete\_gat | **DELETE**     | Delete Gateway |
| i*            | eway** <docs/G | /v2/gateway/{u | by its UUID    |
|               | atewayAPIApi.m | uid}           |                |
|               | d#delete_gatew |                |                |
|               | ay>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *GatewayAPIAp | `**get\_gatewa | **GET**        | Get the        |
| i*            | y\_resources** | /v2/gateway/{u | Resources of a |
|               |  <docs/Gateway | uid}/resource  | Gateway by the |
|               | APIApi.md#get_ |                | Gateway UUID   |
|               | gateway_resour |                |                |
|               | ces>`__        |                |                |
+---------------+----------------+----------------+----------------+
| *GatewayAPIAp | `**query\_gate | **POST**       | Retrieve a     |
| i*            | ways** <docs/G | /v2/gateway/qu | Gateway by a   |
|               | atewayAPIApi.m | ery            | query          |
|               | d#query_gatewa |                |                |
|               | ys>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *GatewayAPIAp | `**retrieve\_g | **GET**        | Retrieve a     |
| i*            | ateways** <doc | /v2/gateway/{u | Gateway by its |
|               | s/GatewayAPIAp | uid}           | UUID           |
|               | i.md#retrieve_ |                |                |
|               | gateways>`__   |                |                |
+---------------+----------------+----------------+----------------+
| *GatewayAPIAp | `**retrieve\_g | **GET**        | Retrieve a     |
| i*            | ateways1** <do | /v2/gateway    | collection of  |
|               | cs/GatewayAPIA |                | Gateways       |
|               | pi.md#retrieve |                |                |
|               | _gateways1>`__ |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**count\_grou | **GET**        | Count Groups   |
|               | ps** <docs/Gro | /v2/group/coun |                |
|               | upAPIApi.md#co | t              |                |
|               | unt_groups>`__ |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**create\_gro | **POST**       | Create a new   |
|               | up** <docs/Gro | /v2/group      | Group          |
|               | upAPIApi.md#cr |                |                |
|               | eate_group>`__ |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**delete\_gro | **DELETE**     | Delete Group   |
|               | up\_branch** < | /v2/group/{uui | branch by the  |
|               | docs/GroupAPIA | d}             | Group UUID     |
|               | pi.md#delete_g |                |                |
|               | roup_branch>`_ |                |                |
|               | _              |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**get\_group\ | **GET**        | Get the        |
|               | _gateways** <d | /v2/group/{uui | Gateways of a  |
|               | ocs/GroupAPIAp | d}/gateway     | Group by the   |
|               | i.md#get_group |                | Group UUID     |
|               | _gateways>`__  |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**get\_group\ | **GET**        | Get the        |
|               | _resources** < | /v2/group/{uui | Resources of a |
|               | docs/GroupAPIA | d}/resource    | Group by the   |
|               | pi.md#get_grou |                | Group UUID     |
|               | p_resources>`_ |                |                |
|               | _              |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**get\_main\_ | **GET**        | List the main  |
|               | level\_groups* | /v2/group/main | level Groups   |
|               | * <docs/GroupA |                |                |
|               | PIApi.md#get_m |                |                |
|               | ain_level_grou |                |                |
|               | ps>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**get\_sub\_g | **GET**        | Get the        |
|               | roups** <docs/ | /v2/group/{uui | Subgroups of a |
|               | GroupAPIApi.md | d}/subgroup/{d | Group by the   |
|               | #get_sub_group | epth}          | Group UUID     |
|               | s>`__          |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**move\_group | **POST**       | Move Group     |
|               | \_branch** <do | /v2/group/move | Branch         |
|               | cs/GroupAPIApi | /{sourceUUID}/ |                |
|               | .md#move_group | {targetUUID}   |                |
|               | _branch>`__    |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**retrieve\_g | **GET**        | Retrieve a     |
|               | roup** <docs/G | /v2/group/{uui | Group by its   |
|               | roupAPIApi.md# | d}             | UUID           |
|               | retrieve_group |                |                |
|               | >`__           |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**retrieve\_g | **GET**        | Retrieve a     |
|               | roups** <docs/ | /v2/group      | collection of  |
|               | GroupAPIApi.md |                | Groups         |
|               | #retrieve_grou |                |                |
|               | ps>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *GroupAPIApi* | `**update\_gro | **POST**       | Update Group   |
|               | up** <docs/Gro | /v2/group/{uui |                |
|               | upAPIApi.md#up | d}             |                |
|               | date_group>`__ |                |                |
+---------------+----------------+----------------+----------------+
| *Participator | `**create\_ps\ | **POST**       | Create a       |
| ySensingAPIAp | _resource** <d | /v2/ps/resourc | Participatory  |
| i*            | ocs/Participat | e              | Sensing        |
|               | orySensingAPIA |                | Resource with  |
|               | pi.md#create_p |                | an             |
|               | s_resource>`__ |                | autogenerated  |
|               |                |                | uri            |
+---------------+----------------+----------------+----------------+
| *Participator | `**delete\_ps\ | **DELETE**     | Delete a       |
| ySensingAPIAp | _resource** <d | /v2/ps/resourc | Participatory  |
| i*            | ocs/Participat | e/{uuid}       | Sensing        |
|               | orySensingAPIA |                | Resource       |
|               | pi.md#delete_p |                |                |
|               | s_resource>`__ |                |                |
+---------------+----------------+----------------+----------------+
| *Participator | `**publish\_ps | **POST**       | Publish data   |
| ySensingAPIAp | \_data** <docs | /v2/ps/data    | to a           |
| i*            | /Participatory |                | Participatory  |
|               | SensingAPIApi. |                | Sensing        |
|               | md#publish_ps_ |                | Resource.      |
|               | data>`__       |                |                |
+---------------+----------------+----------------+----------------+
| *PhenomenonAP | `**create\_phe | **POST**       | Create a       |
| IApi*         | nomenon** <doc | /v2/phenomenon | Phenomenon     |
|               | s/PhenomenonAP |                |                |
|               | IApi.md#create |                |                |
|               | _phenomenon>`_ |                |                |
|               | _              |                |                |
+---------------+----------------+----------------+----------------+
| *PhenomenonAP | `**delete\_phe | **DELETE**     | Delete a       |
| IApi*         | nomenon** <doc | /v2/phenomenon | Phenomenon by  |
|               | s/PhenomenonAP | /{uuid}        | its UUID       |
|               | IApi.md#delete |                |                |
|               | _phenomenon>`_ |                |                |
|               | _              |                |                |
+---------------+----------------+----------------+----------------+
| *PhenomenonAP | `**get\_phenom | **GET**        | Retrieve a     |
| IApi*         | enon\_by\_u\_u | /v2/phenomenon | Phenomenon by  |
|               | id** <docs/Phe | /{uuid}        | its UUID       |
|               | nomenonAPIApi. |                |                |
|               | md#get_phenome |                |                |
|               | non_by_u_uid>` |                |                |
|               | __             |                |                |
+---------------+----------------+----------------+----------------+
| *PhenomenonAP | `**list\_all\_ | **GET**        | Retrieve a     |
| IApi*         | phenomenons**  | /v2/phenomenon | collection of  |
|               | <docs/Phenomen |                | Phenomenons    |
|               | onAPIApi.md#li |                |                |
|               | st_all_phenome |                |                |
|               | nons>`__       |                |                |
+---------------+----------------+----------------+----------------+
| *PhenomenonAP | `**query\_phen | **POST**       | Retrieve a     |
| IApi*         | omenons** <doc | /v2/phenomenon | Phenomenon by  |
|               | s/PhenomenonAP | /query         | a query        |
|               | IApi.md#query_ |                |                |
|               | phenomenons>`_ |                |                |
|               | _              |                |                |
+---------------+----------------+----------------+----------------+
| *PhenomenonAP | `**update\_phe | **POST**       | Update         |
| IApi*         | nomenon** <doc | /v2/phenomenon | Phenomenon     |
|               | s/PhenomenonAP | /{uuid}        |                |
|               | IApi.md#update |                |                |
|               | _phenomenon>`_ |                |                |
|               | _              |                |                |
+---------------+----------------+----------------+----------------+
| *RegistryAPIA | `**query\_regi | **POST**       | Query the      |
| pi*           | stry** <docs/R | /v2/registry/q | Registry       |
|               | egistryAPIApi. | uery           | Service to     |
|               | md#query_regis |                | retrieve a     |
|               | try>`__        |                | collection of  |
|               |                |                | Resources      |
|               |                |                | records with   |
|               |                |                | their last     |
|               |                |                | read value and |
|               |                |                | timestamp by   |
|               |                |                | their UUID     |
+---------------+----------------+----------------+----------------+
| *ResourceAPIA | `**count\_reso | **GET**        | Count          |
| pi*           | urmvnces** <do | /v2/resource/c | Resources      |
|               | cs/ResourceAPI | ount           |                |
|               | Api.md#count_r |                |                |
|               | esourmvnces>`_ |                |                |
|               | _              |                |                |
+---------------+----------------+----------------+----------------+
| *ResourceAPIA | `**create\_res | **POST**       | Create a new   |
| pi*           | ource** <docs/ | /v2/resource   | Resource       |
|               | ResourceAPIApi |                |                |
|               | .md#create_res |                |                |
|               | ource>`__      |                |                |
+---------------+----------------+----------------+----------------+
| *ResourceAPIA | `**delete\_res | **DELETE**     | Delete         |
| pi*           | ource** <docs/ | /v2/resource/{ | Resource by    |
|               | ResourceAPIApi | uuid}          | its UUID       |
|               | .md#delete_res |                |                |
|               | ource>`__      |                |                |
+---------------+----------------+----------------+----------------+
| *ResourceAPIA | `**move\_resou | **POST**       | Move Resource  |
| pi*           | rce** <docs/Re | /v2/resource/{ | by its UUID    |
|               | sourceAPIApi.m | uuid}/move/{ta |                |
|               | d#move_resourc | rgetUUID}      |                |
|               | e>`__          |                |                |
+---------------+----------------+----------------+----------------+
| *ResourceAPIA | `**query\_reso | **POST**       | Retrieve a     |
| pi*           | urces** <docs/ | /v2/resource/q | Resource by a  |
|               | ResourceAPIApi | uery           | query          |
|               | .md#query_reso |                |                |
|               | urces>`__      |                |                |
+---------------+----------------+----------------+----------------+
| *ResourceAPIA | `**retrieve\_r | **GET**        | Retrieve a     |
| pi*           | esource** <doc | /v2/resource/{ | Spark Works    |
|               | s/ResourceAPIA | uuid}          | Resource by    |
|               | pi.md#retrieve |                | its UUID       |
|               | _resource>`__  |                |                |
+---------------+----------------+----------------+----------------+
| *ResourceAPIA | `**retrieve\_r | **GET**        | Retrieve a     |
| pi*           | esources** <do | /v2/resource   | collection of  |
|               | cs/ResourceAPI |                | Resources      |
|               | Api.md#retriev |                |                |
|               | e_resources>`_ |                |                |
|               | _              |                |                |
+---------------+----------------+----------------+----------------+
| *ResourceAPIA | `**update\_res | **POST**       | Update         |
| pi*           | ource** <docs/ | /v2/resource/{ | Resource       |
|               | ResourceAPIApi | uuid}          |                |
|               | .md#update_res |                |                |
|               | ource>`__      |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**create\_uni | **POST**       | Create a Unit  |
|               | t** <docs/Unit | /v2/unit       |                |
|               | APIApi.md#crea |                |                |
|               | te_unit>`__    |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**create\_uni | **POST**       | Create a Unit  |
|               | t\_conversion* | /v2/conversion | Conversion     |
|               | * <docs/UnitAP |                |                |
|               | IApi.md#create |                |                |
|               | _unit_conversi |                |                |
|               | on>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**delete\_uni | **DELETE**     | Delete a Unit  |
|               | t** <docs/Unit | /v2/unit/{uuid | by its UUID    |
|               | APIApi.md#dele | }              |                |
|               | te_unit>`__    |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**delete\_uni | **DELETE**     | Delete a Unit  |
|               | t\_conversion* | /v2/conversion | Conversion by  |
|               | * <docs/UnitAP | /{uuid}        | its UUID       |
|               | IApi.md#delete |                |                |
|               | _unit_conversi |                |                |
|               | on>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**get\_unit\_ | **GET**        | Retrieve a     |
|               | by\_u\_uid** < | /v2/unit/{uuid | Unit by its    |
|               | docs/UnitAPIAp | }              | UUID           |
|               | i.md#get_unit_ |                |                |
|               | by_u_uid>`__   |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**get\_unit\_ | **GET**        | Retrieve a     |
|               | conversion\_by | /v2/conversion | Unit           |
|               | \_u\_uid** <do | /{uuid}        | Conversion by  |
|               | cs/UnitAPIApi. |                | its UUID       |
|               | md#get_unit_co |                |                |
|               | nversion_by_u_ |                |                |
|               | uid>`__        |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**list\_all\_ | **GET**        | Retrieve a     |
|               | unit\_conversi | /v2/conversion | collection of  |
|               | ons** <docs/Un |                | Unit           |
|               | itAPIApi.md#li |                | Conversions    |
|               | st_all_unit_co |                |                |
|               | nversions>`__  |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**list\_all\_ | **GET**        | Retrieve a     |
|               | units** <docs/ | /v2/unit       | collection of  |
|               | UnitAPIApi.md# |                | Units          |
|               | list_all_units |                |                |
|               | >`__           |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**query\_unit | **POST**       | Retrieve a     |
|               | \_conversions* | /v2/conversion | List of Unit   |
|               | * <docs/UnitAP | /query         | Conversions by |
|               | IApi.md#query_ |                | a query        |
|               | unit_conversio |                |                |
|               | ns>`__         |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**query\_unit | **POST**       | Retrieve a     |
|               | s** <docs/Unit | /v2/unit/query | Unit by a      |
|               | APIApi.md#quer |                | query          |
|               | y_units>`__    |                |                |
+---------------+----------------+----------------+----------------+
| *UnitAPIApi*  | `**update\_uni | **POST**       | Update Unit    |
|               | t** <docs/Unit | /v2/unit/{uuid |                |
|               | APIApi.md#upda | }              |                |
|               | te_unit>`__    |                |                |
+---------------+----------------+----------------+----------------+

Documentation For Models
------------------------

-  `AParticipatorySensingResourceRequestAPIModel <docs/AParticipatorySensingResourceRequestAPIModel.md>`__
-  `CollectionOfDataQueryCriteriaRequestAPIModel <docs/CollectionOfDataQueryCriteriaRequestAPIModel.md>`__
-  `CommandAPIModel <docs/CommandAPIModel.md>`__
-  `GatewayCreateDTO <docs/GatewayCreateDTO.md>`__
-  `GatewayDTO <docs/GatewayDTO.md>`__
-  `GatewayQueryDTO <docs/GatewayQueryDTO.md>`__
-  `GroupCreateDTO <docs/GroupCreateDTO.md>`__
-  `GroupDTO <docs/GroupDTO.md>`__
-  `GroupNodeDTO <docs/GroupNodeDTO.md>`__
-  `GroupUpdateDTO <docs/GroupUpdateDTO.md>`__
-  `ListOfParticipatorySensingDataAPIModel <docs/ListOfParticipatorySensingDataAPIModel.md>`__
-  `ListOfQueryCriteriaWithinATimeframeRequestAPIModel <docs/ListOfQueryCriteriaWithinATimeframeRequestAPIModel.md>`__
-  `ParticipatorySensingDataAPIModel <docs/ParticipatorySensingDataAPIModel.md>`__
-  `PhenomenonCreateDTO <docs/PhenomenonCreateDTO.md>`__
-  `PhenomenonDTO <docs/PhenomenonDTO.md>`__
-  `PhenomenonQueryDTO <docs/PhenomenonQueryDTO.md>`__
-  `PhenomenonUpdateDTO <docs/PhenomenonUpdateDTO.md>`__
-  `RegistryPairDTO <docs/RegistryPairDTO.md>`__
-  `RegistryRecordDTO <docs/RegistryRecordDTO.md>`__
-  `ResourceAnalyticsDataResponseAPIModel <docs/ResourceAnalyticsDataResponseAPIModel.md>`__
-  `ResourceCreateDTO <docs/ResourceCreateDTO.md>`__
-  `ResourceDTO <docs/ResourceDTO.md>`__
-  `ResourceLatestDataResponseAPIModel <docs/ResourceLatestDataResponseAPIModel.md>`__
-  `ResourceLatestValuesResponseAPIModel <docs/ResourceLatestValuesResponseAPIModel.md>`__
-  `ResourceQueryCriteriaRequestAPIModel <docs/ResourceQueryCriteriaRequestAPIModel.md>`__
-  `ResourceQueryCriteriaRequestWithinATimeframeAPIModel <docs/ResourceQueryCriteriaRequestWithinATimeframeAPIModel.md>`__
-  `ResourceQueryCriteriaWithinATimeframeResponseAPIModel <docs/ResourceQueryCriteriaWithinATimeframeResponseAPIModel.md>`__
-  `ResourceQueryDTO <docs/ResourceQueryDTO.md>`__
-  `ResourceUpdateDTO <docs/ResourceUpdateDTO.md>`__
-  `SingleResourceMeasurementAPIModel <docs/SingleResourceMeasurementAPIModel.md>`__
-  `TheResourceSummaryDataAPIModel <docs/TheResourceSummaryDataAPIModel.md>`__
-  `UnitConversionCreateDTO <docs/UnitConversionCreateDTO.md>`__
-  `UnitConversionDTO <docs/UnitConversionDTO.md>`__
-  `UnitConversionQueryDTO <docs/UnitConversionQueryDTO.md>`__
-  `UnitCreateDTO <docs/UnitCreateDTO.md>`__
-  `UnitDTO <docs/UnitDTO.md>`__
-  `UnitQueryDTO <docs/UnitQueryDTO.md>`__
-  `UnitUpdateDTO <docs/UnitUpdateDTO.md>`__

Documentation For Authorization
-------------------------------

oauth2
------

-  **Type**: OAuth
-  **Flow**: password
-  **Authorization URL**:
-  **Scopes**:
-  **read**: Description of read scope.

Author
------

info@sparkworks.net
